<?php
/**
 * Features Section options
 *
 * @package Theme Palace
 * @subpackage Careerpress Pro
 * @since Careerpress Pro 1.0.0
 */

// Add Features section
$wp_customize->add_section( 'careerpress_pro_features_section', array(
	'title'             => esc_html__( 'Features','careerpress-pro' ),
	'description'       => esc_html__( 'Features Section options.', 'careerpress-pro' ),
	'panel'             => 'careerpress_pro_front_page_panel',
) );

// Features content enable control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[features_section_enable]', array(
	'default'			=> 	$options['features_section_enable'],
	'sanitize_callback' => 'careerpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Careerpress_Pro_Switch_Control( $wp_customize, 'careerpress_pro_theme_options[features_section_enable]', array(
	'label'             => esc_html__( 'Features Section Enable', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_features_section',
	'on_off_label' 		=> careerpress_pro_switch_options(),
) ) );

// features sub title setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[features_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[features_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_features_section',
	'active_callback' 	=> 'careerpress_pro_is_features_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'careerpress_pro_theme_options[features_sub_title]', array(
		'selector'            => '#our-services .section-header span.section-subtitle',
		'settings'            => 'careerpress_pro_theme_options[features_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'careerpress_pro_features_sub_title_partial',
    ) );
}

// features title setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[features_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[features_title]', array(
	'label'           	=> esc_html__( 'Title', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_features_section',
	'active_callback' 	=> 'careerpress_pro_is_features_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'careerpress_pro_theme_options[features_title]', array(
		'selector'            => '#our-services .section-header h2.section-title',
		'settings'            => 'careerpress_pro_theme_options[features_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'careerpress_pro_features_title_partial',
    ) );
}

// features content type control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[features_column]', array(
	'default'          	=> $options['features_column'],
	'sanitize_callback' => 'careerpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[features_column]', array(
	'label'             => esc_html__( 'Column Layout', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_features_section',
	'type'				=> 'select',
	'active_callback' 	=> 'careerpress_pro_is_features_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'careerpress-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'careerpress-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'careerpress-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[features_count]', array(
	'default'          	=> $options['features_count'],
	'sanitize_callback' => 'careerpress_pro_sanitize_number_range',
	'validate_callback' => 'careerpress_pro_validate_features_count',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[features_count]', array(
	'label'             => esc_html__( 'Number of Features', 'careerpress-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_features_section',
	'active_callback'   => 'careerpress_pro_is_features_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Features content type control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[features_content_type]', array(
	'default'          	=> $options['features_content_type'],
	'sanitize_callback' => 'careerpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[features_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_features_section',
	'type'				=> 'select',
	'active_callback' 	=> 'careerpress_pro_is_features_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'careerpress-pro' ),
		'post' 		=> esc_html__( 'Post', 'careerpress-pro' ),
		'category' 	=> esc_html__( 'Category', 'careerpress-pro' ),
	),
) );

for ( $i = 1; $i <= $options['features_count']; $i++ ) :
	// features control and setting
	$wp_customize->add_setting( 'careerpress_pro_theme_options[features_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Careerpress_Pro_Icon_Picker( $wp_customize, 'careerpress_pro_theme_options[features_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'careerpress-pro' ), $i ),
		'section'           => 'careerpress_pro_features_section',
		'active_callback'	=> 'careerpress_pro_is_features_section_enable',
	) ) );

	// features pages drop down chooser control and setting
	$wp_customize->add_setting( 'careerpress_pro_theme_options[features_content_page_' . $i . ']', array(
		'sanitize_callback' => 'careerpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Careerpress_Pro_Dropdown_Chooser( $wp_customize, 'careerpress_pro_theme_options[features_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'careerpress-pro' ), $i ),
		'section'           => 'careerpress_pro_features_section',
		'choices'			=> careerpress_pro_page_choices(),
		'active_callback'	=> 'careerpress_pro_is_features_section_content_page_enable',
	) ) );

	// features posts drop down chooser control and setting
	$wp_customize->add_setting( 'careerpress_pro_theme_options[features_content_post_' . $i . ']', array(
		'sanitize_callback' => 'careerpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Careerpress_Pro_Dropdown_Chooser( $wp_customize, 'careerpress_pro_theme_options[features_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'careerpress-pro' ), $i ),
		'section'           => 'careerpress_pro_features_section',
		'choices'			=> careerpress_pro_post_choices(),
		'active_callback'	=> 'careerpress_pro_is_features_section_content_post_enable',
	) ) );

	// features hr setting and control
	$wp_customize->add_setting( 'careerpress_pro_theme_options[features_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Careerpress_Pro_Customize_Horizontal_Line( $wp_customize, 'careerpress_pro_theme_options[features_hr_'. $i .']',
		array(
			'section'         => 'careerpress_pro_features_section',
			'active_callback' => 'careerpress_pro_is_features_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'careerpress_pro_theme_options[features_content_category]', array(
	'sanitize_callback' => 'careerpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Careerpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'careerpress_pro_theme_options[features_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'careerpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_features_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'careerpress_pro_is_features_section_content_category_enable'
) ) );
